@@ -1,7 +1,7 @@
 package Bencher::Scenario::JSONDecodeRegexp;
 
-our $DATE = '2016-11-04'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,7 +48,7 @@ Bencher::Scenario::JSONDecodeRegexp - Benchmark JSON decoding
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::JSONDecodeRegexp (from Perl distribution Bencher-Scenarios-JSONDecodeRegexp), released on 2016-11-04.
+This document describes version 0.003 of Bencher::Scenario::JSONDecodeRegexp (from Perl distribution Bencher-Scenarios-JSONDecodeRegexp), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -133,12 +133,12 @@ Benchmark with C<< bencher -m JSONDecodeRegexp --include-path archive/JSON-Decod
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant                     | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
- | JSON::Decode::Regexp::from_json | 0.06   |     11000 |     89    |        1   | 1.1e-07 |      20 |
- | JSON::Decode::Regexp::from_json | 0.03   |     17000 |     57    |        1.5 | 2.9e-07 |      29 |
- | JSON::Decode::Regexp::from_json | 0.04   |     18000 |     54    |        1.6 | 1.9e-07 |      31 |
- | JSON::Decode::Regexp::from_json | 0.09   |    200000 |      6    |       20   | 1.1e-07 |      20 |
- | JSON::PP::decode                |        |    240000 |      4.2  |       21   | 6.7e-09 |      20 |
- | JSON::Decode::Regexp::from_json | 0.07   |    281000 |      3.55 |       25   | 1.6e-09 |      22 |
+ | JSON::Decode::Regexp::from_json | 0.06   |     11000 |     87    |        1   | 1.9e-07 |      24 |
+ | JSON::Decode::Regexp::from_json | 0.03   |     17000 |     60    |        1.4 | 1.9e-07 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.04   |     17000 |     60    |        1.4 | 1.9e-07 |      24 |
+ | JSON::PP::decode                |        |    230000 |      4.3  |       20   | 1.1e-08 |      29 |
+ | JSON::Decode::Regexp::from_json | 0.07   |    280000 |      3.6  |       24   | 6.7e-09 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.09   |    281000 |      3.56 |       24.5 | 1.5e-09 |      24 |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table2#
@@ -146,12 +146,12 @@ Benchmark with C<< bencher -m JSONDecodeRegexp --include-path archive/JSON-Decod
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant                     | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
- | JSON::Decode::Regexp::from_json | 0.06   |      5100 |    200    |        1   | 3.7e-07 |      26 |
- | JSON::Decode::Regexp::from_json | 0.03   |     14000 |     73    |        2.7 | 6.7e-07 |      20 |
- | JSON::Decode::Regexp::from_json | 0.04   |     16000 |     62    |        3.2 |   5e-07 |      25 |
- | JSON::Decode::Regexp::from_json | 0.09   |    100000 |      8    |       20   | 3.4e-07 |      20 |
- | JSON::PP::decode                |        |    133000 |      7.53 |       26.2 | 3.3e-09 |      20 |
- | JSON::Decode::Regexp::from_json | 0.07   |    190000 |      5.4  |       37   | 6.7e-09 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.06   |     11000 |      94   |        1   | 4.5e-07 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.03   |     15000 |      68   |        1.4 | 1.9e-07 |      24 |
+ | JSON::Decode::Regexp::from_json | 0.04   |     16000 |      62   |        1.5 | 1.1e-07 |      20 |
+ | JSON::PP::decode                |        |    130000 |       7.8 |       12   | 8.6e-09 |      27 |
+ | JSON::Decode::Regexp::from_json | 0.07   |    160000 |       6.1 |       15   | 3.5e-08 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.09   |    180000 |       5.5 |       17   | 6.7e-09 |      20 |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table3#
@@ -159,12 +159,12 @@ Benchmark with C<< bencher -m JSONDecodeRegexp --include-path archive/JSON-Decod
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant                     | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
- | JSON::Decode::Regexp::from_json | 0.03   |      7600 |     130   |       1    | 2.4e-07 |      24 |
- | JSON::Decode::Regexp::from_json | 0.06   |      7800 |     130   |       1    | 2.7e-07 |      20 |
- | JSON::Decode::Regexp::from_json | 0.04   |     13000 |      77.1 |       1.7  | 2.5e-08 |      22 |
- | JSON::Decode::Regexp::from_json | 0.09   |     30000 |      40   |       4    | 1.5e-06 |      20 |
- | JSON::PP::decode                |        |     28000 |      35   |       3.7  | 4.9e-08 |      24 |
- | JSON::Decode::Regexp::from_json | 0.07   |     41000 |      24.4 |       5.38 | 6.7e-09 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.03   |      7700 |     130   |       1    | 2.7e-07 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.06   |      8700 |     110   |       1.1  | 2.1e-07 |      21 |
+ | JSON::Decode::Regexp::from_json | 0.04   |     12000 |      86   |       1.5  | 1.1e-07 |      20 |
+ | JSON::PP::decode                |        |     29000 |      35   |       3.7  | 5.3e-08 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.07   |     40000 |      30   |       5    | 4.9e-07 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.09   |     39000 |      25.7 |       5.09 | 1.2e-08 |      24 |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table4#
@@ -172,12 +172,12 @@ Benchmark with C<< bencher -m JSONDecodeRegexp --include-path archive/JSON-Decod
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant                     | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
- | JSON::Decode::Regexp::from_json | 0.03   |      1300 |       780 |       1    | 1.1e-06 |      20 |
- | JSON::PP::decode                |        |      2000 |       500 |       2    | 1.9e-05 |      23 |
- | JSON::Decode::Regexp::from_json | 0.06   |      3100 |       330 |       2.4  | 4.7e-07 |      21 |
- | JSON::Decode::Regexp::from_json | 0.09   |      3700 |       270 |       2.8  | 1.1e-06 |      20 |
- | JSON::Decode::Regexp::from_json | 0.04   |      3820 |       262 |       2.97 | 2.1e-07 |      20 |
- | JSON::Decode::Regexp::from_json | 0.07   |      4700 |       210 |       3.6  | 2.7e-07 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.03   |      1300 |       768 |       1    | 6.4e-07 |      20 |
+ | JSON::PP::decode                |        |      3200 |       320 |       2.4  | 3.1e-06 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.06   |      3400 |       300 |       2.6  | 4.1e-07 |      22 |
+ | JSON::Decode::Regexp::from_json | 0.04   |      3410 |       293 |       2.62 | 2.6e-07 |      21 |
+ | JSON::Decode::Regexp::from_json | 0.09   |      4500 |       220 |       3.5  | 4.3e-07 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.07   |      4700 |       210 |       3.6  | 2.4e-07 |      25 |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table5#
@@ -185,12 +185,12 @@ Benchmark with C<< bencher -m JSONDecodeRegexp --include-path archive/JSON-Decod
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant                     | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
- | JSON::Decode::Regexp::from_json | 0.06   |     10000 |        99 |        1   | 2.9e-07 |      28 |
- | JSON::Decode::Regexp::from_json | 0.03   |     17000 |        58 |        1.7 | 5.5e-07 |      21 |
- | JSON::Decode::Regexp::from_json | 0.04   |     19000 |        53 |        1.9 | 1.1e-07 |      20 |
- | JSON::PP::decode                |        |    250000 |         4 |       25   | 6.7e-09 |      20 |
- | JSON::Decode::Regexp::from_json | 0.09   |    330000 |         3 |       33   | 3.3e-09 |      20 |
- | JSON::Decode::Regexp::from_json | 0.07   |    340000 |         3 |       33   | 1.4e-08 |      31 |
+ | JSON::Decode::Regexp::from_json | 0.06   |     11000 |      87   |       1    | 1.3e-07 |      21 |
+ | JSON::Decode::Regexp::from_json | 0.04   |     17300 |      58   |       1.51 | 2.7e-08 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.03   |     19000 |      53   |       1.6  |   1e-07 |      21 |
+ | JSON::PP::decode                |        |    230000 |       4.4 |      20    | 6.7e-09 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.09   |    333000 |       3   |      29.1  | 6.9e-10 |      29 |
+ | JSON::Decode::Regexp::from_json | 0.07   |    380000 |       2.7 |      33    | 3.3e-09 |      20 |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table6#
@@ -198,12 +198,12 @@ Benchmark with C<< bencher -m JSONDecodeRegexp --include-path archive/JSON-Decod
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant                     | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
- | JSON::Decode::Regexp::from_json | 0.04   |      7100 |     140   |        1   | 6.7e-07 |      20 |
- | JSON::Decode::Regexp::from_json | 0.06   |      8000 |     120   |        1.1 |   6e-07 |      27 |
- | JSON::Decode::Regexp::from_json | 0.03   |     10000 |     100   |        1   | 2.3e-06 |      20 |
- | JSON::Decode::Regexp::from_json | 0.07   |     75000 |      13   |       11   | 5.3e-08 |      23 |
- | JSON::PP::decode                |        |    100000 |       9.7 |       14   | 1.4e-08 |      30 |
- | JSON::Decode::Regexp::from_json | 0.09   |    120000 |       8.4 |       17   |   3e-08 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.06   |      8900 |    110    |        1   | 3.6e-07 |      28 |
+ | JSON::Decode::Regexp::from_json | 0.03   |     13000 |     74    |        1.5 | 1.1e-07 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.04   |     14000 |     71    |        1.6 | 1.3e-07 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.07   |     78000 |     13    |        8.8 | 2.7e-08 |      20 |
+ | JSON::PP::decode                |        |     87000 |     12    |        9.7 | 1.2e-08 |      24 |
+ | JSON::Decode::Regexp::from_json | 0.09   |    123000 |      8.16 |       13.7 | 3.2e-09 |      22 |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table7#
@@ -211,12 +211,12 @@ Benchmark with C<< bencher -m JSONDecodeRegexp --include-path archive/JSON-Decod
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant                     | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
- | JSON::Decode::Regexp::from_json | 0.03   |      4300 |       230 |        1   | 2.2e-06 |      20 |
- | JSON::Decode::Regexp::from_json | 0.06   |      4600 |       220 |        1.1 | 9.3e-07 |      29 |
- | JSON::Decode::Regexp::from_json | 0.04   |      6000 |       170 |        1.4 | 1.3e-06 |      20 |
- | JSON::Decode::Regexp::from_json | 0.07   |     11000 |        95 |        2.4 | 1.8e-07 |      21 |
- | JSON::PP::decode                |        |     17000 |        60 |        3.8 | 1.1e-07 |      20 |
- | JSON::Decode::Regexp::from_json | 0.09   |     19000 |        52 |        4.4 |   1e-07 |      22 |
+ | JSON::Decode::Regexp::from_json | 0.03   |    4200   |   240     |    1       | 6.9e-07 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.06   |    5100   |   190     |    1.2     | 2.6e-07 |      21 |
+ | JSON::Decode::Regexp::from_json | 0.04   |    6200   |   160     |    1.5     | 3.9e-07 |      24 |
+ | JSON::Decode::Regexp::from_json | 0.07   |   11000   |    88     |    2.7     | 1.1e-07 |      27 |
+ | JSON::PP::decode                |        |   15000   |    69     |    3.5     | 8.4e-08 |      32 |
+ | JSON::Decode::Regexp::from_json | 0.09   |   19302.4 |    51.807 |    4.58605 |   0     |      20 |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table8#
@@ -224,12 +224,12 @@ Benchmark with C<< bencher -m JSONDecodeRegexp --include-path archive/JSON-Decod
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant                     | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
- | JSON::Decode::Regexp::from_json | 0.03   |       400 |     2     |       1    | 2.6e-05 |      20 |
- | JSON::Decode::Regexp::from_json | 0.06   |      1000 |     1     |       2    | 1.2e-05 |      20 |
- | JSON::Decode::Regexp::from_json | 0.07   |      1090 |     0.918 |       2.61 | 9.1e-07 |      20 |
- | JSON::Decode::Regexp::from_json | 0.04   |      1100 |     0.9   |       2.7  | 1.3e-06 |      20 |
- | JSON::PP::decode                |        |      1500 |     0.66  |       3.6  | 1.2e-06 |      20 |
- | JSON::Decode::Regexp::from_json | 0.09   |      2100 |     0.49  |       4.9  | 1.1e-06 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.03   |       430 |     2.3   |       1    | 9.1e-06 |      25 |
+ | JSON::Decode::Regexp::from_json | 0.06   |      1000 |     0.96  |       2.4  | 1.8e-06 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.04   |      1100 |     0.93  |       2.5  | 1.5e-06 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.07   |      1200 |     0.85  |       2.7  | 1.1e-06 |      20 |
+ | JSON::PP::decode                |        |      1510 |     0.663 |       3.52 | 4.8e-07 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.09   |      2070 |     0.482 |       4.84 | 2.6e-07 |      21 |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table9#
@@ -237,14 +237,17 @@ Benchmark with C<< bencher -m JSONDecodeRegexp --include-path archive/JSON-Decod
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant                     | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
- | JSON::Decode::Regexp::from_json | 0.06   |      9100 |     110   |        1   |   4e-07 |      23 |
- | JSON::Decode::Regexp::from_json | 0.04   |     13000 |      75   |        1.5 | 3.2e-07 |      20 |
- | JSON::Decode::Regexp::from_json | 0.03   |     14000 |      71   |        1.5 | 2.1e-07 |      20 |
- | JSON::PP::decode                |        |     16300 |      61.2 |        1.8 | 2.7e-08 |      20 |
- | JSON::Decode::Regexp::from_json | 0.07   |     50000 |      20   |        6   | 8.1e-07 |      28 |
- | JSON::Decode::Regexp::from_json | 0.09   |    100000 |       9.8 |       11   | 1.7e-08 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.06   |      9200 | 110       |     1      | 2.1e-07 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.04   |     13000 |  78       |     1.4    | 2.7e-07 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.03   |     14000 |  71       |     1.5    | 2.7e-07 |      28 |
+ | JSON::PP::decode                |        |     16000 |  61       |     1.8    |   8e-08 |      20 |
+ | JSON::Decode::Regexp::from_json | 0.07   |     80000 |  10       |     9      | 1.8e-07 |      31 |
+ | JSON::Decode::Regexp::from_json | 0.09   |    107785 |   9.27774 |    11.7003 |   0     |      20 |
  +---------------------------------+--------+-----------+-----------+------------+---------+---------+
 
+
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-JSONDecodeRegexp>.
@@ -267,7 +270,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
