@@ -1,7 +1,7 @@
 package Bencher::Scenario::JSONDecodeRegexp::Startup;
 
-our $DATE = '2016-11-04'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -34,7 +34,7 @@ Bencher::Scenario::JSONDecodeRegexp::Startup - Benchmark startup overhead of JSO
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::JSONDecodeRegexp::Startup (from Perl distribution Bencher-Scenarios-JSONDecodeRegexp), released on 2016-11-04.
+This document describes version 0.003 of Bencher::Scenario::JSONDecodeRegexp::Startup (from Perl distribution Bencher-Scenarios-JSONDecodeRegexp), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -82,17 +82,20 @@ Benchmark with C<< bencher -m JSONDecodeRegexp::Startup --include-path archive/J
 
  #table1#
  {dataset=>undef}
- +----------------------+--------+-----------+------------------------+------------+-----------+---------+
- | participant          | modver | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
- +----------------------+--------+-----------+------------------------+------------+-----------+---------+
- | Regexp::Grammars     |        |      26   |                   24   |        1   |   0.00015 |      20 |
- | JSON::Decode::Regexp | 0.03   |       7   |                    5   |        3   |   0.00029 |      20 |
- | JSON::Decode::Regexp | 0.06   |       5.4 |                    3.4 |        4.8 |   2e-05   |      21 |
- | JSON::Decode::Regexp | 0.09   |       5.1 |                    3.1 |        5   | 2.6e-05   |      20 |
- | JSON::Decode::Regexp | 0.04   |       5.1 |                    3.1 |        5   | 3.6e-05   |      20 |
- | JSON::Decode::Regexp | 0.07   |       5   |                    3   |        5.1 | 1.8e-05   |      20 |
- | perl -e1 (baseline)  |        |       2   |                    0   |       10   | 2.7e-05   |      20 |
- +----------------------+--------+-----------+------------------------+------------+-----------+---------+
+ +-------------------------+---------------+-----------+----------------------+--------+-----------+------------------------+------------+---------+---------+
+ | proc_private_dirty_size | proc_rss_size | proc_size | participant          | modver | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +-------------------------+---------------+-----------+----------------------+--------+-----------+------------------------+------------+---------+---------+
+ | 0.82                    | 4.2           | 16        | Regexp::Grammars     |        |      25   |                   23.1 |        1   | 5.5e-05 |      20 |
+ | 3.7                     | 7.3           | 29        | JSON::Decode::Regexp | 0.09   |       5.3 |                    3.4 |        4.8 | 1.9e-05 |      20 |
+ | 3.7                     | 7.4           | 29        | JSON::Decode::Regexp | 0.07   |       5.2 |                    3.3 |        4.8 | 2.6e-05 |      20 |
+ | 3.7                     | 7.3           | 29        | JSON::Decode::Regexp | 0.06   |       5.2 |                    3.3 |        4.8 | 3.9e-05 |      20 |
+ | 3.7                     | 7.5           | 29        | JSON::Decode::Regexp | 0.03   |       5.1 |                    3.2 |        4.9 | 2.4e-05 |      20 |
+ | 3.7                     | 7.4           | 29        | JSON::Decode::Regexp | 0.04   |       5   |                    3.1 |        5   | 2.4e-05 |      20 |
+ | 0.99                    | 4.3           | 16        | perl -e1 (baseline)  |        |       1.9 |                    0   |       13   | 6.5e-06 |      20 |
+ +-------------------------+---------------+-----------+----------------------+--------+-----------+------------------------+------------+---------+---------+
+
+
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -116,7 +119,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
